@@ -6,7 +6,7 @@ with the serialization of PCall requests.
 from json import JSONEncoder, JSONDecoder
 
 from javascriptasync.core.jslogging import log_warning
-from .errors import InvalidNodeOp
+from .errorsjs import InvalidNodeOp
 from typing import Any, Tuple
 
 
@@ -25,17 +25,20 @@ from typing import Any, Tuple
 
 # You're better off just using a custom Decoder.
 
+
 class JSONRequestDecoder(JSONDecoder):
-    def decode(self, s:str):
+    # pylint: disable=arguments-differ
+    def decode(self, s: str): #type:ignore
         """Return the Python representation of ``s`` (a ``str`` instance
         containing a JSON document).
 
         """
         decoded_obj = super().decode(s)
-        if isinstance(decoded_obj, dict) and 'r' in decoded_obj:
+        if isinstance(decoded_obj, dict) and "r" in decoded_obj:
             return decoded_obj, True
         return s, False
 
+
 class CustomJSONCountEncoder(JSONEncoder):
     """
     A custom JSON Encoder used by the Executor's Pcall methods, which
@@ -45,6 +48,7 @@ class CustomJSONCountEncoder(JSONEncoder):
     Attributes:
         append_p (bool): Determines whether to append the value of ctr.
         ctr (int): Counter value.
+        problem (int): Issues found when encoding.
         expect_reply (bool): Defines if a reply is expected.
         wanted (dict) : Holds wanted objects.
     """
@@ -62,7 +66,7 @@ class CustomJSONCountEncoder(JSONEncoder):
             self.append_p = kwargs.pop("append_p")
         super().__init__(*args, **kwargs)
         self.ctr = 0
-        self.problem=0
+        self.problem = 0
         self.expect_reply = False
         self.wanted = {}
 
@@ -96,6 +100,7 @@ class CustomJSONCountEncoder(JSONEncoder):
     def default(self, o):
         """
         Increments the counter and checks if object has 'ffid' attribute.
+        Will also assign any non-primitive objects to the self.wanted dictionary.
 
         Args:
             o (object): The object to be checked.
@@ -104,12 +109,12 @@ class CustomJSONCountEncoder(JSONEncoder):
             dict: If 'ffid' exists returns ffid, else returns 'r', 'ffid' and updates wanted dict.
         """
         self.ctr += 1
-        pro=o
+        pro = o
         if hasattr(pro, "node_op"):
             if pro.node_op:
                 log_warning(f"passed in arg {pro} is an unprocessed chain! ")
-                self.ctr-=1
-                self.problem+=1
+                self.ctr -= 1
+                self.problem += 1
                 return {"no": "UNPROCESSED CHAIN."}
         if hasattr(pro, "ffid"):
             return {"ffid": pro.ffid}
@@ -135,8 +140,8 @@ class CustomJSONCountEncoder(JSONEncoder):
         flocals = o["args"][1]
         for k in _locals:
             v = _locals[k]
-            #or (v is True) or (v is False)
-            if isinstance(v, (int, float,bool))  or (v is None):
+            # or (v is True) or (v is False)
+            if isinstance(v, (int, float, bool)) or (v is None):
                 flocals[k] = v
             else:
                 flocals[k] = self.default(v)
@@ -159,7 +164,7 @@ class CustomJSONCountEncoder(JSONEncoder):
             chunks = list(chunks)
         # cl = len(chunks) - 1
         chunk_append = []
-        if self.ctr<=0 and self.problem>=1:
+        if self.ctr <= 0 and self.problem >= 1:
             raise InvalidNodeOp("please check your code...")
         doappend = self.append_p
         for c in chunks:
